@@ -1,8 +1,8 @@
-from Cocoa import *
-from CoreData import *
+import Cocoa
+import CoreData
 import objc
 
-class DragAppAppDelegate (NSObject):
+class DragAppAppDelegate (Cocoa.NSObject):
     clubWindow = objc.IBOutlet()
     peopleWindow = objc.IBOutlet()
 
@@ -12,24 +12,22 @@ class DragAppAppDelegate (NSObject):
 
     def managedObjectModel(self):
         if self._managedObjectModel is None:
-            allBundles = NSMutableSet.alloc().init()
-            allBundles.addObject_(NSBundle.mainBundle())
-            allBundles.addObjectsFromArray_(NSBundle.allFrameworks())
+            allBundles = Cocoa.NSMutableSet.alloc().init()
+            allBundles.addObject_(Cocoa.NSBundle.mainBundle())
+            allBundles.addObjectsFromArray_(Cocoa.NSBundle.allFrameworks())
 
-            self._managedObjectModel = NSManagedObjectModel.mergedModelFromBundles_(allBundles.allObjects())
+            self._managedObjectModel = CoreData.NSManagedObjectModel.mergedModelFromBundles_(allBundles.allObjects())
 
         return self._managedObjectModel
 
-
-
     # Change this path/code to point to your App's data store.
     def applicationSupportFolder(self):
-        paths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, True)
+        paths = Cocoa.NSSearchPathForDirectoriesInDomains(Cocoa.NSApplicationSupportDirectory, Cocoa.NSUserDomainMask, True)
 
         if len(paths) == 0:
-            NSRunAlertPanel("Alert", "Can't find application support folder",
+            Cocoa.NSRunAlertPanel("Alert", "Can't find application support folder",
                     "Quit", None, None)
-            NSApplication.sharedApplication().terminate_(self)
+            Cocoa.NSApplication.sharedApplication().terminate_(self)
         else:
             applicationSupportFolder = paths[0].stringByAppendingPathComponent_("DragApp")
 
@@ -37,28 +35,27 @@ class DragAppAppDelegate (NSObject):
 
     def managedObjectContext(self):
         if self._managedObjectContext is None:
-            fileManager = NSFileManager.defaultManager()
+            fileManager = Cocoa.NSFileManager.defaultManager()
             applicationSupportFolder = self.applicationSupportFolder()
 
             if not fileManager.fileExistsAtPath_isDirectory_(applicationSupportFolder, None)[0]:
                 fileManager.createDirectoryAtPath_attributes_(
                         applicationSupportFolder, None)
 
-            url = NSURL.fileURLWithPath_(
+            url = Cocoa.NSURL.fileURLWithPath_(
                     applicationSupportFolder.stringByAppendingPathComponent_(
                         "DragApp.xml"))
 
-            coordinator = NSPersistentStoreCoordinator.alloc().initWithManagedObjectModel_(self.managedObjectModel())
-            result, error = coordinator.addPersistentStoreWithType_configuration_URL_options_error_(NSXMLStoreType, None, url, None, None)
+            coordinator = CoreData.NSPersistentStoreCoordinator.alloc().initWithManagedObjectModel_(self.managedObjectModel())
+            result, error = coordinator.addPersistentStoreWithType_configuration_URL_options_error_(CoreData.NSXMLStoreType, None, url, None, None)
             if result:
-                self._managedObjectContext = NSManagedObjectContext.alloc().init()
+                self._managedObjectContext = CoreData.NSManagedObjectContext.alloc().init()
                 self._managedObjectContext.setPersistentStoreCoordinator_(coordinator)
             else:
-                NSApplication.sharedApplication().presentError_(error)
+                Cocoa.NSApplication.sharedApplication().presentError_(error)
 
         return self._managedObjectContext
 
-
     def windowWillReturnUndoManager_(self, window):
         return self.managedObjectContext().undoManager()
 
@@ -66,12 +63,12 @@ class DragAppAppDelegate (NSObject):
     def saveAction_(self, sender):
         res, error = self.managedObjectContext().save_(None)
         if not res:
-            NSApplication.sharedApplication().presentError_(error)
+            Cocoa.NSApplication.sharedApplication().presentError_(error)
 
     def applicationShouldTerminate_(self, sender):
         context = self.managedObjectContext()
 
-        reply = NSTerminateNow;
+        reply = Cocoa.NSTerminateNow;
 
         if context is not None:
             if context.commitEditing():
@@ -81,18 +78,18 @@ class DragAppAppDelegate (NSObject):
                     # changed to make sure the error presented includes
                     # application specific error recovery. For now, simply
                     # display 2 panels.
-                    errorResult = NSApplication.sharedApplication().presentError_(error)
+                    errorResult = Cocoa.NSApplication.sharedApplication().presentError_(error)
 
                     if errorResult: # Then the error was handled
-                        reply = NSTerminateCancel
+                        reply = Cocoa.NSTerminateCancel
                     else:
                         # Error handling wasn't implemented. Fall back to
                         # displaying a "quit anyway" panel.
-                        alertReturn = NSRunAlertPanel(None, "Could not save changes while quitting. Quit anyway?" , "Quit anyway", "Cancel", None)
-                        if alertReturn == NSAlertAlternateReturn:
-                            reply = NSTerminateCancel;
+                        alertReturn = Cocoa.NSRunAlertPanel(None, "Could not save changes while quitting. Quit anyway?" , "Quit anyway", "Cancel", None)
+                        if alertReturn == Cocoa.NSAlertAlternateReturn:
+                            reply = Cocoa.NSTerminateCancel;
 
             else:
-                reply = NSTerminateCancel
+                reply = Cocoa.NSTerminateCancel
 
         return reply
